# longpython

[![PyPI](https://img.shields.io/pypi/v/longpython?color=blue)](https://pypi.org/project/longpython/)

_looooooooooooooooooooong python!_

## Usage

```shellsession
$ longpython
  _
(" ヽ
   \ \
   / /
   \ \ _ ,
    \___/

$ longpython -h
usage: longpython [-h] [-l INT]

CLI tool to print long python

optional arguments:
  -h, --help            show this help message and exit
  -l INT, --length INT  length of python (default: 1)
```

## Installation

longpython requires python 3.9 or later.

### Via pipx (recommended)

I recommend using [pipx](https://github.com/pypa/pipx) to install this project.

```sh
pipx install longpython
```

### Via pip

```sh
pip install longpython
```

### Download Single File

The project does not have any dependencies, you can download
[this file](./longpython/main.py) and use as soon as.

## Derived Projects

- [syumai/longify](https://github.com/syumai/longify): A command to output
  longified any ascii art
- [arrow2nd/longdeno](https://github.com/arrow2nd/longdeno):
  Looooooooooooooooooooooooooooooooooooooooooooooong [Deno](https://deno.land)
- [ikanago/longferris](https://github.com/ikanago/longferris): Long
  [Ferris](https://github.com/ciusji/ferris) written in Rust
- [sheepla/longgopher](https://github.com/sheepla/longgopher): ʕ◉ϖ◉ʔ
  loooooooooooooooooooooong gopher

## License

MIT
